@@ -5,14 +5,15 @@
 using namespace std;
 
 
-MINE::MINE(double alpha, double c)
+MINE::MINE(double alpha, double c, int est)
 {
   char *ret;
-  
+
   param.alpha = alpha;
   param.c = c;
+  param.est = est;
   score = NULL;
-  
+
   ret = mine_check_parameter(&param);
   if (ret)
     throw ret;
@@ -30,7 +31,7 @@ void MINE::compute_score(double *x, double *y, int n)
   prob.x = x;
   prob.y = y;
   prob.n = n;
-  
+
   mine_free_score(&score);
   score = mine_compute_score(&prob, &param);
   char *ret = "error in mine_compute_score()";
@@ -44,7 +45,7 @@ double MINE::mic()
   char *ret = "no score computed";
   if (score == NULL)
     throw ret;
-  
+
   return mine_mic(score);
 }
 
@@ -54,7 +55,7 @@ double MINE::mas()
   char *ret = "no score computed";
   if (score == NULL)
     throw ret;
-  
+
   return mine_mas(score);
 }
 
@@ -64,7 +65,7 @@ double MINE::mev()
   char *ret = "no score computed";
   if (score == NULL)
     throw ret;
-  
+
   return mine_mev(score);
 }
 
@@ -84,6 +85,26 @@ double MINE::mcn_general()
   char *ret = "no score computed";
   if (score == NULL)
     throw ret;
-  
+
   return mine_mcn_general(score);
 }
+
+
+double MINE::tic(int norm)
+{
+  char *ret = "no score computed";
+  if (score == NULL)
+    throw ret;
+
+  return mine_tic(score, norm);
+}
+
+
+double MINE::gmic(double p)
+{
+  char *ret = "no score computed";
+  if (score == NULL)
+    throw ret;
+
+  return mine_gmic(score, p);
+}
